==> istio-model-v1alpha3-5.11.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/TLSMatchAttributesFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class TLSMatchAttributesFluentImpl<A extends io.fabric8.istio.api.networking.v1alpha3.TLSMatchAttributesFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.istio.api.networking.v1alpha3.TLSMatchAttributesFluent<A>{
  public TLSMatchAttributesFluentImpl() {
  }
  public TLSMatchAttributesFluentImpl(io.fabric8.istio.api.networking.v1alpha3.TLSMatchAttributes instance) {
    this.withDestinationSubnets(instance.getDestinationSubnets()); 
    this.withGateways(instance.getGateways()); 
    this.withPort(instance.getPort()); 
    this.withSniHosts(instance.getSniHosts()); 
    this.withSourceLabels(instance.getSourceLabels()); 
    this.withSourceNamespace(instance.getSourceNamespace()); 
  }
  private java.util.List<java.lang.String> destinationSubnets;
  private java.util.List<java.lang.String> gateways;
  private java.lang.Integer port;
  private java.util.List<java.lang.String> sniHosts;
  private java.util.Map<java.lang.String,java.lang.String> sourceLabels;
  private java.lang.String sourceNamespace;
  public A addToDestinationSubnets(java.lang.Integer index,java.lang.String item) {
    if (this.destinationSubnets == null) {this.destinationSubnets = new java.util.ArrayList<java.lang.String>();}
    this.destinationSubnets.add(index, item);
    return (A)this;
  }
  public A setToDestinationSubnets(java.lang.Integer index,java.lang.String item) {
    if (this.destinationSubnets == null) {this.destinationSubnets = new java.util.ArrayList<java.lang.String>();}
    this.destinationSubnets.set(index, item); return (A)this;
  }
  public A addToDestinationSubnets(java.lang.String... items) {
    if (this.destinationSubnets == null) {this.destinationSubnets = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.destinationSubnets.add(item);} return (A)this;
  }
  public A addAllToDestinationSubnets(java.util.Collection<java.lang.String> items) {
    if (this.destinationSubnets == null) {this.destinationSubnets = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.destinationSubnets.add(item);} return (A)this;
  }
  public A removeFromDestinationSubnets(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.destinationSubnets!= null){ this.destinationSubnets.remove(item);}} return (A)this;
  }
  public A removeAllFromDestinationSubnets(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.destinationSubnets!= null){ this.destinationSubnets.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getDestinationSubnets() {
    return this.destinationSubnets;
  }
  public java.lang.String getDestinationSubnet(java.lang.Integer index) {
    return this.destinationSubnets.get(index);
  }
  public java.lang.String getFirstDestinationSubnet() {
    return this.destinationSubnets.get(0);
  }
  public java.lang.String getLastDestinationSubnet() {
    return this.destinationSubnets.get(destinationSubnets.size() - 1);
  }
  public java.lang.String getMatchingDestinationSubnet(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: destinationSubnets) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingDestinationSubnet(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: destinationSubnets) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withDestinationSubnets(java.util.List<java.lang.String> destinationSubnets) {
    if (destinationSubnets != null) {this.destinationSubnets = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : destinationSubnets){this.addToDestinationSubnets(item);}} else { this.destinationSubnets = null;} return (A) this;
  }
  public A withDestinationSubnets(java.lang.String... destinationSubnets) {
    if (this.destinationSubnets != null) {this.destinationSubnets.clear();}
    if (destinationSubnets != null) {for (java.lang.String item :destinationSubnets){ this.addToDestinationSubnets(item);}} return (A) this;
  }
  public java.lang.Boolean hasDestinationSubnets() {
    return destinationSubnets != null && !destinationSubnets.isEmpty();
  }
  public A addNewDestinationSubnet(java.lang.String arg0) {
    return (A)addToDestinationSubnets(new String(arg0));
  }
  public A addToGateways(java.lang.Integer index,java.lang.String item) {
    if (this.gateways == null) {this.gateways = new java.util.ArrayList<java.lang.String>();}
    this.gateways.add(index, item);
    return (A)this;
  }
  public A setToGateways(java.lang.Integer index,java.lang.String item) {
    if (this.gateways == null) {this.gateways = new java.util.ArrayList<java.lang.String>();}
    this.gateways.set(index, item); return (A)this;
  }
  public A addToGateways(java.lang.String... items) {
    if (this.gateways == null) {this.gateways = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.gateways.add(item);} return (A)this;
  }
  public A addAllToGateways(java.util.Collection<java.lang.String> items) {
    if (this.gateways == null) {this.gateways = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.gateways.add(item);} return (A)this;
  }
  public A removeFromGateways(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.gateways!= null){ this.gateways.remove(item);}} return (A)this;
  }
  public A removeAllFromGateways(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.gateways!= null){ this.gateways.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getGateways() {
    return this.gateways;
  }
  public java.lang.String getGateway(java.lang.Integer index) {
    return this.gateways.get(index);
  }
  public java.lang.String getFirstGateway() {
    return this.gateways.get(0);
  }
  public java.lang.String getLastGateway() {
    return this.gateways.get(gateways.size() - 1);
  }
  public java.lang.String getMatchingGateway(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: gateways) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingGateway(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: gateways) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withGateways(java.util.List<java.lang.String> gateways) {
    if (gateways != null) {this.gateways = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : gateways){this.addToGateways(item);}} else { this.gateways = null;} return (A) this;
  }
  public A withGateways(java.lang.String... gateways) {
    if (this.gateways != null) {this.gateways.clear();}
    if (gateways != null) {for (java.lang.String item :gateways){ this.addToGateways(item);}} return (A) this;
  }
  public java.lang.Boolean hasGateways() {
    return gateways != null && !gateways.isEmpty();
  }
  public A addNewGateway(java.lang.String arg0) {
    return (A)addToGateways(new String(arg0));
  }
  public java.lang.Integer getPort() {
    return this.port;
  }
  public A withPort(java.lang.Integer port) {
    this.port=port; return (A) this;
  }
  public java.lang.Boolean hasPort() {
    return this.port != null;
  }
  public A addToSniHosts(java.lang.Integer index,java.lang.String item) {
    if (this.sniHosts == null) {this.sniHosts = new java.util.ArrayList<java.lang.String>();}
    this.sniHosts.add(index, item);
    return (A)this;
  }
  public A setToSniHosts(java.lang.Integer index,java.lang.String item) {
    if (this.sniHosts == null) {this.sniHosts = new java.util.ArrayList<java.lang.String>();}
    this.sniHosts.set(index, item); return (A)this;
  }
  public A addToSniHosts(java.lang.String... items) {
    if (this.sniHosts == null) {this.sniHosts = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.sniHosts.add(item);} return (A)this;
  }
  public A addAllToSniHosts(java.util.Collection<java.lang.String> items) {
    if (this.sniHosts == null) {this.sniHosts = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.sniHosts.add(item);} return (A)this;
  }
  public A removeFromSniHosts(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.sniHosts!= null){ this.sniHosts.remove(item);}} return (A)this;
  }
  public A removeAllFromSniHosts(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.sniHosts!= null){ this.sniHosts.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getSniHosts() {
    return this.sniHosts;
  }
  public java.lang.String getSniHost(java.lang.Integer index) {
    return this.sniHosts.get(index);
  }
  public java.lang.String getFirstSniHost() {
    return this.sniHosts.get(0);
  }
  public java.lang.String getLastSniHost() {
    return this.sniHosts.get(sniHosts.size() - 1);
  }
  public java.lang.String getMatchingSniHost(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: sniHosts) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingSniHost(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: sniHosts) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withSniHosts(java.util.List<java.lang.String> sniHosts) {
    if (sniHosts != null) {this.sniHosts = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : sniHosts){this.addToSniHosts(item);}} else { this.sniHosts = null;} return (A) this;
  }
  public A withSniHosts(java.lang.String... sniHosts) {
    if (this.sniHosts != null) {this.sniHosts.clear();}
    if (sniHosts != null) {for (java.lang.String item :sniHosts){ this.addToSniHosts(item);}} return (A) this;
  }
  public java.lang.Boolean hasSniHosts() {
    return sniHosts != null && !sniHosts.isEmpty();
  }
  public A addNewSniHost(java.lang.String arg0) {
    return (A)addToSniHosts(new String(arg0));
  }
  public A addToSourceLabels(java.lang.String key,java.lang.String value) {
    if(this.sourceLabels == null && key != null && value != null) { this.sourceLabels = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(key != null && value != null) {this.sourceLabels.put(key, value);} return (A)this;
  }
  public A addToSourceLabels(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.sourceLabels == null && map != null) { this.sourceLabels = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(map != null) { this.sourceLabels.putAll(map);} return (A)this;
  }
  public A removeFromSourceLabels(java.lang.String key) {
    if(this.sourceLabels == null) { return (A) this; }
    if(key != null && this.sourceLabels != null) {this.sourceLabels.remove(key);} return (A)this;
  }
  public A removeFromSourceLabels(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.sourceLabels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.sourceLabels != null){this.sourceLabels.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getSourceLabels() {
    return this.sourceLabels;
  }
  public <K,V>A withSourceLabels(java.util.Map<java.lang.String,java.lang.String> sourceLabels) {
    if (sourceLabels == null) { this.sourceLabels =  null;} else {this.sourceLabels = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(sourceLabels);} return (A) this;
  }
  public java.lang.Boolean hasSourceLabels() {
    return this.sourceLabels != null;
  }
  public java.lang.String getSourceNamespace() {
    return this.sourceNamespace;
  }
  public A withSourceNamespace(java.lang.String sourceNamespace) {
    this.sourceNamespace=sourceNamespace; return (A) this;
  }
  public java.lang.Boolean hasSourceNamespace() {
    return this.sourceNamespace != null;
  }
  
  /**
   * Method is deprecated. use withSourceNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewSourceNamespace(java.lang.String arg0) {
    return (A)withSourceNamespace(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TLSMatchAttributesFluentImpl that = (TLSMatchAttributesFluentImpl) o;
    if (destinationSubnets != null ? !destinationSubnets.equals(that.destinationSubnets) :that.destinationSubnets != null) return false;
    if (gateways != null ? !gateways.equals(that.gateways) :that.gateways != null) return false;
    if (port != null ? !port.equals(that.port) :that.port != null) return false;
    if (sniHosts != null ? !sniHosts.equals(that.sniHosts) :that.sniHosts != null) return false;
    if (sourceLabels != null ? !sourceLabels.equals(that.sourceLabels) :that.sourceLabels != null) return false;
    if (sourceNamespace != null ? !sourceNamespace.equals(that.sourceNamespace) :that.sourceNamespace != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(destinationSubnets,  gateways,  port,  sniHosts,  sourceLabels,  sourceNamespace,  super.hashCode());
  }
  
}

==> istio-model-v1alpha3-5.12.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/TLSMatchAttributesFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class TLSMatchAttributesFluentImpl<A extends io.fabric8.istio.api.networking.v1alpha3.TLSMatchAttributesFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.istio.api.networking.v1alpha3.TLSMatchAttributesFluent<A>{
  public TLSMatchAttributesFluentImpl() {
  }
  public TLSMatchAttributesFluentImpl(io.fabric8.istio.api.networking.v1alpha3.TLSMatchAttributes instance) {
    this.withDestinationSubnets(instance.getDestinationSubnets()); 
    this.withGateways(instance.getGateways()); 
    this.withPort(instance.getPort()); 
    this.withSniHosts(instance.getSniHosts()); 
    this.withSourceLabels(instance.getSourceLabels()); 
    this.withSourceNamespace(instance.getSourceNamespace()); 
  }
  private java.util.List<java.lang.String> destinationSubnets;
  private java.util.List<java.lang.String> gateways;
  private java.lang.Integer port;
  private java.util.List<java.lang.String> sniHosts;
  private java.util.Map<java.lang.String,java.lang.String> sourceLabels;
  private java.lang.String sourceNamespace;
  public A addToDestinationSubnets(java.lang.Integer index,java.lang.String item) {
    if (this.destinationSubnets == null) {this.destinationSubnets = new java.util.ArrayList<java.lang.String>();}
    this.destinationSubnets.add(index, item);
    return (A)this;
  }
  public A setToDestinationSubnets(java.lang.Integer index,java.lang.String item) {
    if (this.destinationSubnets == null) {this.destinationSubnets = new java.util.ArrayList<java.lang.String>();}
    this.destinationSubnets.set(index, item); return (A)this;
  }
  public A addToDestinationSubnets(java.lang.String... items) {
    if (this.destinationSubnets == null) {this.destinationSubnets = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.destinationSubnets.add(item);} return (A)this;
  }
  public A addAllToDestinationSubnets(java.util.Collection<java.lang.String> items) {
    if (this.destinationSubnets == null) {this.destinationSubnets = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.destinationSubnets.add(item);} return (A)this;
  }
  public A removeFromDestinationSubnets(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.destinationSubnets!= null){ this.destinationSubnets.remove(item);}} return (A)this;
  }
  public A removeAllFromDestinationSubnets(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.destinationSubnets!= null){ this.destinationSubnets.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getDestinationSubnets() {
    return this.destinationSubnets;
  }
  public java.lang.String getDestinationSubnet(java.lang.Integer index) {
    return this.destinationSubnets.get(index);
  }
  public java.lang.String getFirstDestinationSubnet() {
    return this.destinationSubnets.get(0);
  }
  public java.lang.String getLastDestinationSubnet() {
    return this.destinationSubnets.get(destinationSubnets.size() - 1);
  }
  public java.lang.String getMatchingDestinationSubnet(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: destinationSubnets) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingDestinationSubnet(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: destinationSubnets) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withDestinationSubnets(java.util.List<java.lang.String> destinationSubnets) {
    if (destinationSubnets != null) {this.destinationSubnets = new java.util.ArrayList(); for (java.lang.String item : destinationSubnets){this.addToDestinationSubnets(item);}} else { this.destinationSubnets = null;} return (A) this;
  }
  public A withDestinationSubnets(java.lang.String... destinationSubnets) {
    if (this.destinationSubnets != null) {this.destinationSubnets.clear();}
    if (destinationSubnets != null) {for (java.lang.String item :destinationSubnets){ this.addToDestinationSubnets(item);}} return (A) this;
  }
  public java.lang.Boolean hasDestinationSubnets() {
    return destinationSubnets != null && !destinationSubnets.isEmpty();
  }
  public A addNewDestinationSubnet(java.lang.String arg0) {
    return (A)addToDestinationSubnets(new String(arg0));
  }
  public A addToGateways(java.lang.Integer index,java.lang.String item) {
    if (this.gateways == null) {this.gateways = new java.util.ArrayList<java.lang.String>();}
    this.gateways.add(index, item);
    return (A)this;
  }
  public A setToGateways(java.lang.Integer index,java.lang.String item) {
    if (this.gateways == null) {this.gateways = new java.util.ArrayList<java.lang.String>();}
    this.gateways.set(index, item); return (A)this;
  }
  public A addToGateways(java.lang.String... items) {
    if (this.gateways == null) {this.gateways = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.gateways.add(item);} return (A)this;
  }
  public A addAllToGateways(java.util.Collection<java.lang.String> items) {
    if (this.gateways == null) {this.gateways = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.gateways.add(item);} return (A)this;
  }
  public A removeFromGateways(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.gateways!= null){ this.gateways.remove(item);}} return (A)this;
  }
  public A removeAllFromGateways(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.gateways!= null){ this.gateways.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getGateways() {
    return this.gateways;
  }
  public java.lang.String getGateway(java.lang.Integer index) {
    return this.gateways.get(index);
  }
  public java.lang.String getFirstGateway() {
    return this.gateways.get(0);
  }
  public java.lang.String getLastGateway() {
    return this.gateways.get(gateways.size() - 1);
  }
  public java.lang.String getMatchingGateway(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: gateways) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingGateway(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: gateways) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withGateways(java.util.List<java.lang.String> gateways) {
    if (gateways != null) {this.gateways = new java.util.ArrayList(); for (java.lang.String item : gateways){this.addToGateways(item);}} else { this.gateways = null;} return (A) this;
  }
  public A withGateways(java.lang.String... gateways) {
    if (this.gateways != null) {this.gateways.clear();}
    if (gateways != null) {for (java.lang.String item :gateways){ this.addToGateways(item);}} return (A) this;
  }
  public java.lang.Boolean hasGateways() {
    return gateways != null && !gateways.isEmpty();
  }
  public A addNewGateway(java.lang.String arg0) {
    return (A)addToGateways(new String(arg0));
  }
  public java.lang.Integer getPort() {
    return this.port;
  }
  public A withPort(java.lang.Integer port) {
    this.port=port; return (A) this;
  }
  public java.lang.Boolean hasPort() {
    return this.port != null;
  }
  public A addToSniHosts(java.lang.Integer index,java.lang.String item) {
    if (this.sniHosts == null) {this.sniHosts = new java.util.ArrayList<java.lang.String>();}
    this.sniHosts.add(index, item);
    return (A)this;
  }
  public A setToSniHosts(java.lang.Integer index,java.lang.String item) {
    if (this.sniHosts == null) {this.sniHosts = new java.util.ArrayList<java.lang.String>();}
    this.sniHosts.set(index, item); return (A)this;
  }
  public A addToSniHosts(java.lang.String... items) {
    if (this.sniHosts == null) {this.sniHosts = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.sniHosts.add(item);} return (A)this;
  }
  public A addAllToSniHosts(java.util.Collection<java.lang.String> items) {
    if (this.sniHosts == null) {this.sniHosts = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.sniHosts.add(item);} return (A)this;
  }
  public A removeFromSniHosts(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.sniHosts!= null){ this.sniHosts.remove(item);}} return (A)this;
  }
  public A removeAllFromSniHosts(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.sniHosts!= null){ this.sniHosts.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getSniHosts() {
    return this.sniHosts;
  }
  public java.lang.String getSniHost(java.lang.Integer index) {
    return this.sniHosts.get(index);
  }
  public java.lang.String getFirstSniHost() {
    return this.sniHosts.get(0);
  }
  public java.lang.String getLastSniHost() {
    return this.sniHosts.get(sniHosts.size() - 1);
  }
  public java.lang.String getMatchingSniHost(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: sniHosts) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingSniHost(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: sniHosts) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withSniHosts(java.util.List<java.lang.String> sniHosts) {
    if (sniHosts != null) {this.sniHosts = new java.util.ArrayList(); for (java.lang.String item : sniHosts){this.addToSniHosts(item);}} else { this.sniHosts = null;} return (A) this;
  }
  public A withSniHosts(java.lang.String... sniHosts) {
    if (this.sniHosts != null) {this.sniHosts.clear();}
    if (sniHosts != null) {for (java.lang.String item :sniHosts){ this.addToSniHosts(item);}} return (A) this;
  }
  public java.lang.Boolean hasSniHosts() {
    return sniHosts != null && !sniHosts.isEmpty();
  }
  public A addNewSniHost(java.lang.String arg0) {
    return (A)addToSniHosts(new String(arg0));
  }
  public A addToSourceLabels(java.lang.String key,java.lang.String value) {
    if(this.sourceLabels == null && key != null && value != null) { this.sourceLabels = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.sourceLabels.put(key, value);} return (A)this;
  }
  public A addToSourceLabels(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.sourceLabels == null && map != null) { this.sourceLabels = new java.util.LinkedHashMap(); }
    if(map != null) { this.sourceLabels.putAll(map);} return (A)this;
  }
  public A removeFromSourceLabels(java.lang.String key) {
    if(this.sourceLabels == null) { return (A) this; }
    if(key != null && this.sourceLabels != null) {this.sourceLabels.remove(key);} return (A)this;
  }
  public A removeFromSourceLabels(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.sourceLabels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.sourceLabels != null){this.sourceLabels.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getSourceLabels() {
    return this.sourceLabels;
  }
  public <K,V>A withSourceLabels(java.util.Map<java.lang.String,java.lang.String> sourceLabels) {
    if (sourceLabels == null) { this.sourceLabels =  null;} else {this.sourceLabels = new java.util.LinkedHashMap(sourceLabels);} return (A) this;
  }
  public java.lang.Boolean hasSourceLabels() {
    return this.sourceLabels != null;
  }
  public java.lang.String getSourceNamespace() {
    return this.sourceNamespace;
  }
  public A withSourceNamespace(java.lang.String sourceNamespace) {
    this.sourceNamespace=sourceNamespace; return (A) this;
  }
  public java.lang.Boolean hasSourceNamespace() {
    return this.sourceNamespace != null;
  }
  
  /**
   * Method is deprecated. use withSourceNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewSourceNamespace(java.lang.String arg0) {
    return (A)withSourceNamespace(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TLSMatchAttributesFluentImpl that = (TLSMatchAttributesFluentImpl) o;
    if (destinationSubnets != null ? !destinationSubnets.equals(that.destinationSubnets) :that.destinationSubnets != null) return false;
    if (gateways != null ? !gateways.equals(that.gateways) :that.gateways != null) return false;
    if (port != null ? !port.equals(that.port) :that.port != null) return false;
    if (sniHosts != null ? !sniHosts.equals(that.sniHosts) :that.sniHosts != null) return false;
    if (sourceLabels != null ? !sourceLabels.equals(that.sourceLabels) :that.sourceLabels != null) return false;
    if (sourceNamespace != null ? !sourceNamespace.equals(that.sourceNamespace) :that.sourceNamespace != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(destinationSubnets,  gateways,  port,  sniHosts,  sourceLabels,  sourceNamespace,  super.hashCode());
  }
  
}
